==> HorsePower-1.11.2-1.3.1.17-sources.jar: se/gory_moon/horsepower/client/renderer/TileEntityGrindstoneRender.java <==
package se.gory_moon.horsepower.client.renderer;

import net.minecraft.block.state.IBlockState;
import net.minecraft.client.Minecraft;
import net.minecraft.client.renderer.*;
import net.minecraft.client.renderer.block.model.IBakedModel;
import net.minecraft.client.renderer.vertex.DefaultVertexFormats;
import net.minecraft.item.ItemStack;
import org.lwjgl.opengl.GL11;
import se.gory_moon.horsepower.blocks.BlockGrindstone;
import se.gory_moon.horsepower.client.renderer.modelvariants.GrindStoneModels;
import se.gory_moon.horsepower.tileentity.TileEntityGrindstone;

public class TileEntityGrindstoneRender extends TileEntityHPBaseRenderer<TileEntityGrindstone> {

    @Override
    public void func_180535_a(TileEntityGrindstone te, double x, double y, double z, float partialTicks, int destroyStage) {
        IBlockState blockState = te.func_145831_w().func_180495_p( te.func_174877_v() );
        ItemStack outputStack = te.func_70301_a(1);
        if (blockState.func_177229_b(BlockGrindstone.FILLED)) {
            Tessellator tessellator = Tessellator.func_178181_a();
            VertexBuffer buffer = tessellator.func_178180_c();
            BlockRendererDispatcher dispatcher = Minecraft.func_71410_x().func_175602_ab();

            IBlockState filledState = blockState.func_177226_a(BlockGrindstone.PART, GrindStoneModels.FILLED);
            IBakedModel filledModel = dispatcher.func_175023_a().func_178125_b(filledState);

            setRenderSettings();

            buffer.func_181668_a(GL11.GL_QUADS, DefaultVertexFormats.field_176600_a);
            buffer.func_178969_c(-te.func_174877_v().func_177958_n(), -te.func_174877_v().func_177956_o(), -te.func_174877_v().func_177952_p());

            dispatcher.func_175019_b().func_178267_a(te.func_145831_w(), filledModel, filledState, te.func_174877_v(), buffer, false);

            GlStateManager.func_179094_E();
            GlStateManager.func_179137_b(x, y, z);

            GlStateManager.func_179137_b( 0.5, 0.5, 0.5 );
            float maxStackSize = outputStack.func_77976_d() > 0 ? outputStack.func_77976_d(): 1F;
            float fillState = 0.23F * (((float)outputStack.func_190916_E()) / maxStackSize);
            GlStateManager.func_179137_b( 0, -0.187 + fillState, 0 );
            GlStateManager.func_179137_b( -0.5, -0.5, -0.5 );

            tessellator.func_78381_a();
            GlStateManager.func_179121_F();
            buffer.func_178969_c(0.0D, 0.0D, 0.0D);
            RenderHelper.func_74519_b();
        } else if (outputStack.func_190926_b()) {
            te.renderStack = ItemStack.field_190927_a;
            te.grindColor = null;
        }

        if (te.hasWorker())
            renderLeash(te.getWorker(), x, y, z, 0D, 0D, 0D, partialTicks, te.func_174877_v());

        GlStateManager.func_179094_E();
        GlStateManager.func_179137_b(x, y, z);
        renderItem(te, te.func_70301_a(0), 0.5F, 1F, 0.5F, 1F);
        if (!te.func_70301_a(0).func_190926_b() && func_178459_a().func_175623_d(te.func_174877_v().func_177984_a()))
            drawString(te, String.valueOf(te.func_70301_a(0).func_190916_E()), 0, 0.35,  0);
        GlStateManager.func_179121_F();

        super.func_180535_a(te, x, y, z, partialTicks, destroyStage);
    }
}

==> HorsePower-1.11.2-1.4.0.20-sources.jar: se/gory_moon/horsepower/client/renderer/TileEntityGrindstoneRender.java <==
package se.gory_moon.horsepower.client.renderer;

import net.minecraft.block.state.IBlockState;
import net.minecraft.client.Minecraft;
import net.minecraft.client.renderer.*;
import net.minecraft.client.renderer.block.model.IBakedModel;
import net.minecraft.client.renderer.vertex.DefaultVertexFormats;
import net.minecraft.item.ItemStack;
import org.lwjgl.opengl.GL11;
import se.gory_moon.horsepower.blocks.BlockGrindstone;
import se.gory_moon.horsepower.client.renderer.modelvariants.GrindStoneModels;
import se.gory_moon.horsepower.tileentity.TileEntityGrindstone;

public class TileEntityGrindstoneRender extends TileEntityHPBaseRenderer<TileEntityGrindstone> {

    @Override
    public void func_180535_a(TileEntityGrindstone te, double x, double y, double z, float partialTicks, int destroyStage) {
        IBlockState blockState = te.func_145831_w().func_180495_p( te.func_174877_v() );
        ItemStack outputStack = te.func_70301_a(1);
        ItemStack secondaryStack = te.func_70301_a(2);
        if (outputStack.func_190916_E() < secondaryStack.func_190916_E())
            outputStack = secondaryStack;

        if (blockState.func_177229_b(BlockGrindstone.FILLED)) {
            Tessellator tessellator = Tessellator.func_178181_a();
            VertexBuffer buffer = tessellator.func_178180_c();
            BlockRendererDispatcher dispatcher = Minecraft.func_71410_x().func_175602_ab();

            IBlockState filledState = blockState.func_177226_a(BlockGrindstone.PART, GrindStoneModels.FILLED);
            IBakedModel filledModel = dispatcher.func_175023_a().func_178125_b(filledState);

            setRenderSettings();

            buffer.func_181668_a(GL11.GL_QUADS, DefaultVertexFormats.field_176600_a);
            buffer.func_178969_c(-te.func_174877_v().func_177958_n(), -te.func_174877_v().func_177956_o(), -te.func_174877_v().func_177952_p());

            dispatcher.func_175019_b().func_178267_a(te.func_145831_w(), filledModel, filledState, te.func_174877_v(), buffer, false);

            GlStateManager.func_179094_E();
            GlStateManager.func_179137_b(x, y, z);

            GlStateManager.func_179137_b( 0.5, 0.5, 0.5 );
            float maxStackSize = outputStack.func_77976_d() > 0 ? outputStack.func_77976_d(): 1F;
            float fillState = 0.23F * (((float)outputStack.func_190916_E()) / maxStackSize);
            GlStateManager.func_179137_b( 0, -0.187 + fillState, 0 );
            GlStateManager.func_179137_b( -0.5, -0.5, -0.5 );

            tessellator.func_78381_a();
            GlStateManager.func_179121_F();
            buffer.func_178969_c(0.0D, 0.0D, 0.0D);
            RenderHelper.func_74519_b();
        } else if (outputStack.func_190926_b()) {
            te.renderStack = ItemStack.field_190927_a;
            te.grindColor = null;
        }

        if (te.hasWorker())
            renderLeash(te.getWorker(), x, y, z, 0D, 0D, 0D, partialTicks, te.func_174877_v());

        GlStateManager.func_179094_E();
        GlStateManager.func_179137_b(x, y, z);
        renderItem(te, te.func_70301_a(0), 0.5F, 1F, 0.5F, 1F);
        if (!te.func_70301_a(0).func_190926_b() && func_178459_a().func_175623_d(te.func_174877_v().func_177984_a()))
            drawString(te, String.valueOf(te.func_70301_a(0).func_190916_E()), 0, 0.35,  0);
        GlStateManager.func_179121_F();

        super.func_180535_a(te, x, y, z, partialTicks, destroyStage);
    }
}
